clear
close all

set(0,'defaultAxesFontSize',18);
set(0,'defaultAxesFontName','times');
set(0,'defaultTextFontSize',18);
set(0,'defaultTextFontName','times');
set(0,'DefaultFigureColormap', jet);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% "LSP_XXX.mat"フォルダ指定
folder = "data";
% プロット結果の画像保存
shouldSaveImage = true;
% 画像保存先
figFolder = "fig";
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

addpath(folder, figFolder)

%Meas. name (1: Yuraku, 2: NTT, 3: WP)
for measSel = 1:3

    switch measSel
        case 1 % 第一有楽ビル
            name = "Yuraku";
            TxLabel = "Yuraku bldg.";
            geoLimitLat = [35.4414,35.4633];
            geoLimitLon = [139.6229,139.6444];
            freqStrTab = {'2_4GHz', '4_8GHz'};
            R = [1 2 3]; % Route No.
        case 2 % NTT 横浜山下ビル
            name = "NTT";
            TxLabel = "NTT Com.";
            geoLimitLat = [35.4374,35.4526];
            geoLimitLon = [139.6337,139.6539];
            freqStrTab = {'2_4GHz', '4_8GHz'};
            R = [4 5]; % Route No.
        case 3 % ワールドポーターズ
            name = "WP";
            TxLabel = "WP";
            geoLimitLat = [35.4466,35.4591];
            geoLimitLon = [139.632,139.648];
            freqStrTab = {'4_8GHz'};
            R = 6; % Route No.
    end


    % Frequency (2_4GHz or 4_8GHz)
    for freqStr = freqStrTab

        % Variable name to be displayed as heatmap
        for cv = {'PG', 'DS', 'ASD', 'ASA'}  % (PG/MD/DS/ASD/ASA)

            % Load LSP table
            load(fullfile(folder, "LSP_"+name+".mat"),"LSP")
            heatmapPlotFlag = true;
            dataExtract;

            %% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            % Tx pos. plot
            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            TxLat = LSP.("freq_"+freqStr).("R"+R(end)).TxLat(1); % Latitude of Tx
            TxLon = LSP.("freq_"+freqStr).("R"+R(end)).TxLon(1); % Longitude of Tx
            geoplot(TxLat, TxLon, 'ob', 'MarkerFaceColor', 'w'); hold on;

            % Draw concentric circles
            r = [0.5, 1, 1.5, 2]; % Radius [km]
            for n = 1:length(r)
                wgs84 = wgs84Ellipsoid("km");
                [lat,lon] = scircle1(TxLat, TxLon, r(n), [], wgs84);
                geoplot(lat,lon,'LineStyle', '--', 'Color', '#808080');
            end

            %% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            % Heatmap
            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            RxLSPTab = [];
            for ii=1:length(R)
                temp = LSP.("freq_"+freqStr).("R"+R(ii));
                temp.DS = temp.DS/1e-6;
                RxLSPTab = [RxLSPTab; temp];
                RxLat = LSP.("freq_"+freqStr).("R"+R(ii)).RxLat; % Latitude of Rx
                RxLon = LSP.("freq_"+freqStr).("R"+R(ii)).RxLon; % Longitude of Rx
            end

            s = geoscatter(RxLSPTab,'RxLat','RxLon',...
                'filled','ColorVariable',cv,'SizeData',20);

            geolimits(geoLimitLat, geoLimitLon);

            hold off;
            c = colorbar('FontName', 'Times New Roman', 'FontSize', 18);

            switch string(cv)
                case "PG"
                    units = '[dB]';
                case "DS"
                    units = '[us]';
                case "ASA"
                    units = '[deg.]';
                    clim([50 200])
                case "ASD"
                    units = '[deg.]';
                    if measSel == 3
                        clim([50 100])
                    else
                        clim([30 60])
                    end
                otherwise
                    units = '[dB]';
            end

            c.Title.String = units;
            text(TxLat, TxLon, "  "+TxLabel);

            gx = gca;
            gx.LatitudeLabel.String  = [];
            gx.LongitudeLabel.String = [];
            gx.LatitudeAxis.Visible = "off";
            gx.LongitudeAxis.Visible = "off";

            title(name + " " + cv + " " + strrep(freqStr,"_","."), ...
                'Interpreter','none', 'FontSize', 18, 'FontName', 'times');

            if shouldSaveImage
                saveas(gcf, fullfile(figFolder, char(strcat(name,'_', cv, '_', freqStr,'.png'))), 'png')
            end
        end
    end
end